@@ -2,7 +2,7 @@
 import inspect
 import warnings
 from django.db import models
-from django.db.models import fields
+from django.db.models import fields, ImageField
 from django.db.models.fields import related
 from django.contrib.contenttypes.generic import GenericRelation
 from django.utils.datastructures import SortedDict
@@ -12,6 +12,7 @@ from autofixture import constraints, generators, signals
 from autofixture.values import Values
 
 
+
 class CreateInstanceError(Exception):
     pass
 
@@ -81,7 +82,6 @@ class AutoFixtureBase(object):
 
         * ``XMLField``
         * ``FileField``
-        * ``ImageField``
 
         Patches are welcome.
     '''
@@ -110,6 +110,7 @@ class AutoFixtureBase(object):
         (fields.IPAddressField, generators.IPAddressGenerator),
         (fields.TextField, generators.LoremGenerator),
         (fields.TimeField, generators.TimeGenerator),
+        (ImageField, generators.ImageGenerator),
     ))
 
     field_values = Values()
@@ -356,6 +357,8 @@ class AutoFixtureBase(object):
                     min_value=-field.MAX_BIGINT - 1,
                     max_value=field.MAX_BIGINT,
                     **kwargs)
+        if isinstance(field, ImageField):
+            return generators.ImageGenerator(**kwargs)
         for field_class, generator in self.field_to_generator.items():
             if isinstance(field, field_class):
                 return generator(**kwargs)
